/**
 * Hook for signing out of a wallet after a user has logged in using `useLogin`
 *
 * @example
 * ```jsx
 * import { useLogout } from "@thirdweb-dev/react";
 *
 * function App() {
 *   const { logout, isLoading } = useLogout();
 *
 *   return (
 *     <button onClick={() => logout()}>
 *       {isLoading ? "Logging out..." : "Logout"}
 *     </button>
 *   );
 * }
 * ```
 *
 * @returns object containing a `logout` function and an `isLoading` state that indicates if the logout request is in progress
 *
 * @auth
 */
export declare function useLogout(): {
    logout: import("@tanstack/react-query").UseMutateAsyncFunction<void, unknown, void, unknown>;
    isLoading: boolean;
};
//# sourceMappingURL=useLogout.d.ts.map